@@ -36,7 +36,7 @@
 
 from __future__ import print_function, division, absolute_import
 
-import logging
+import datetime
 import re
 
 try:
@@ -63,7 +63,6 @@ from ..compat import as_text
 from ..vertica import messages
 from ..vertica.column import Column
 
-logger = logging.getLogger('vertica')
 
 UTF_8 = 'utf-8'
 
@@ -87,8 +86,9 @@ class Cursor(object):
     # NOTE: this is used in executemany and is here for pandas compatibility
     _insert_statement = re.compile(RE_BASIC_INSERT_STAT, re.U | re.I)
 
-    def __init__(self, connection, cursor_type=None, unicode_error=None):
+    def __init__(self, connection, logger, cursor_type=None, unicode_error=None):
         self.connection = connection
+        self._logger = logger
         self.cursor_type = cursor_type
         self.unicode_error = unicode_error if unicode_error is not None else 'strict'
         self._closed = False
@@ -326,6 +326,7 @@ class Cursor(object):
         while True:
             message = self.connection.read_message()
 
+            self._message = message
             if isinstance(message, messages.ErrorResponse):
                 raise errors.QueryError.from_error_response(message, sql)
 
@@ -378,8 +379,10 @@ class Cursor(object):
 
                 if isinstance(param, string_types):
                     param = self.format_quote(as_text(param), is_csv)
+                elif isinstance(param, (datetime.datetime, datetime.date, datetime.time)):
+                    param = self.format_quote(as_text(str(param)), is_csv)
                 elif param is None:
-                    param = NULL
+                    param = '' if is_csv else NULL
                 else:
                     param = str(param)
                 value = as_text(param)
@@ -394,8 +397,10 @@ class Cursor(object):
             for param in parameters:
                 if isinstance(param, string_types):
                     param = self.format_quote(as_text(param), is_csv)
+                elif isinstance(param, (datetime.datetime, datetime.date, datetime.time)):
+                    param = self.format_quote(as_text(str(param)), is_csv)
                 elif param is None:
-                    param = NULL
+                    param = '' if is_csv else NULL
                 else:
                     param = str(param)
                 value = as_text(param)
@@ -411,6 +416,6 @@ class Cursor(object):
     def format_quote(self, param, is_csv):
         # TODO Make sure adapt() behaves properly
         if is_csv:
-            return '"{0}"'.format(re.escape(param))
+            return u'"{0}"'.format(re.escape(param))
         else:
             return QuotedString(param.encode(UTF_8, self.unicode_error)).getquoted()
