@@ -33,6 +33,14 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+"""
+ReadyForQuery message
+
+The backend informs the frontend that it may safely send a new command.
+The ReadyForQuery message is the same one that the backend will issue after each
+command cycle.
+"""
+
 from __future__ import print_function, division, absolute_import
 
 from struct import unpack
@@ -53,5 +61,8 @@ class ReadyForQuery(BackendMessage):
         BackendMessage.__init__(self)
         self.transaction_status = self.STATUSES[unpack('c', data)[0]]
 
+    def __str__(self):
+        return "ReadyForQuery: status = {}".format(self.transaction_status)
+
 
 BackendMessage.register(ReadyForQuery)
