@@ -33,6 +33,15 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+"""
+Query message
+
+In the simple query protocol, the frontend sends a Query message, which contains
+an SQL command (or commands) expressed as a text string. The backend then sends
+one or more response messages depending on the contents of the query command
+string, and finally a ReadyForQuery message.
+"""
+
 from __future__ import print_function, division, absolute_import
 
 from struct import pack
